@@ -1,14 +1,15 @@
 from abstract_utilities import SingletonMeta
-from abstract_solana import Client,abstract_solana_rate_limited_call,RateLimiter,get_insert_list
+from abstract_solana import make_call,get_rpc_dict,Client,abstract_solana_rate_limited_call,RateLimiter,get_insert_list
 from .solcatcherCalls import *
 from ..utils import *
-from abstract_apis import get_async_response,get_json_response,make_request,get_url,make_endpoint,get_headers,get_async_response
+import requests,json
+from abstract_apis import postRpcRequest,get_async_response,get_json_response,make_request,get_url,make_endpoint,get_headers,get_async_response,get_headers
 from abstract_database import get_from_db,get_table,get_db_vars,connectionManager,get_first_row_as_dict
 import json,asyncio
 def call_rate_limit(method=None,status_code=False):
   return FlaskRequest(endpoint='rate_limit',method=get_method(method),get_post='POST',response_result='url',status_code=status_code)
-def call_log_response(method=None,response=None,status_code=False):
-  return FlaskRequest(endpoint='log_response',method=get_method(method),response=get_resp(response) ,get_post='POST',status_code=status_code)
+def call_log_response(method=None,response=None,retry_after=None):
+  return requests.post(url='https://solcatcher.io/flask/log_response',data=json.dumps({"method":get_method(method),"response":get_resp(response),"retry_after":retry_after}),headers=get_headers())
 class CheckSolcatcher(metaclass=SingletonMeta):
   def __init__(self,env_path=None, dbType=None, dbName=None):
     if not hasattr(self, 'initialized'):
@@ -16,7 +17,6 @@ class CheckSolcatcher(metaclass=SingletonMeta):
       self.initialized = True
       self.solcatcher_on = True
       self.solcatcher_db_on=False
-      input(call_rate_limit('test_method',True))
       url,self.status_code = call_rate_limit('test_method',True)
       self.env_path= env_path or get_env_path()
       if self.status_code != 200 and url == None:
@@ -157,6 +157,20 @@ def call_solcatcher_db_api(method,*args,**kwargs):
             rate_limit(method,insertValue)
             insert_db(dbName,insertTable,key=searchValue, value=insertValue,tableName=tableName)
     return insertValue
+def convert_to_lower(string_obj):
+    return ''.join(f"_{char.lower()}" if char.isupper() else char for char in str(string_obj))
 
-
-
+def abstract_solcatcher_rate_limited_call(method, *args, **kwargs):
+    # Build the request body
+    if '-' not in method:
+      method = convert_to_lower(method)
+    body = get_rpc_dict(method, *args, **kwargs)
+    body_method = body.get('method')
+    url = call_rate_limit(method=body_method)
+    response,status_code,retry_after = make_call(url,body)   
+    call_log_response(method=body_method, response=response,retry_after=retry_after)
+    if "api.mainnet-beta.solana.com" in url and status_code == 429:
+        url = call_rate_limit(method='get_url_2')
+        response,status_code,retry_after = make_call(url,body)
+        call_log_response(method=body_method, response=response)
+    return response
